// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <time.h>

#include <qlabel.h>
#include <qlayout.h>
#include <qlined.h>
#include <qpushbt.h>

#include <kseparator.h>
#include <ktablistbox.h>

#include "Archive.h"
#include "ArchiveInfoDlg.h"
#include "Tape.h"

ArchiveInfoDlg::ArchiveInfoDlg( Tape* tape, Archive* archive, QWidget* parent, const char* name )
        : QDialog( parent, name, TRUE ),
          _tape( tape ),
          _archive( archive )
{
    setCaption( "KDat: Archive Info" );
    setIconText( "KDat: Archive Info" );

    resize( 500, 300 );

    QLabel* lbl1 = new QLabel( "Archive name:", this );
    lbl1->setFixedSize( lbl1->sizeHint() );

    _archiveName = new QLineEdit( this );
    _archiveName->setFixedHeight( _archiveName->sizeHint().height() );

    QLabel* lbl2 = new QLabel( "Files:", this );
    lbl2->setFixedHeight( lbl2->sizeHint().height() );
    
    KTabListBox* files = new KTabListBox( this, 0, 3 );
    files->setColumn( 0, "Name", 280 );
    files->setColumn( 1, "Date", 120 );
    files->setColumn( 2, "Size", 140 );

    KSeparator* separator = new KSeparator( this );

    QPushButton* ok     = new QPushButton( "OK"    , this );
    QPushButton* apply  = new QPushButton( "Apply" , this );
    QPushButton* cancel = new QPushButton( "Cancel", this );

    ok->setFixedSize( 80, ok->sizeHint().height() );
    apply->setFixedSize( 80, apply->sizeHint().height() );
    cancel->setFixedSize( 80, cancel->sizeHint().height() );

    connect( ok    , SIGNAL( clicked() ), this, SLOT( slotOK()     ) );
    connect( apply , SIGNAL( clicked() ), this, SLOT( slotApply()  ) );
    connect( cancel, SIGNAL( clicked() ), this, SLOT( slotCancel() ) );

    QVBoxLayout* l1 = new QVBoxLayout( this, 4, 4 );

    QHBoxLayout* l1_1 = new QHBoxLayout();
    l1->addLayout( l1_1 );
    l1_1->addWidget( lbl1 );
    l1_1->addWidget( _archiveName, 1 );

    l1->addSpacing( 4 );
    l1->addWidget( lbl2 );
    l1->addWidget( files, 1 );
    l1->addWidget( separator );

    QHBoxLayout* l1_2 = new QHBoxLayout();
    l1->addLayout( l1_2 );
    l1_2->addStretch( 1 );
    l1_2->addWidget( ok );
    l1_2->addWidget( apply );
    l1_2->addWidget( cancel );

    _archiveName->setText( _archive->name() );

    QListIterator<File> i( _archive->files() );
    QString tmp;
    int j;
    for ( j = 0, i.toFirst(); i.current(); ++i, j++ ) {
        files->appendItem( i.current()->name() );
        time_t tm = i.current()->mtime();
        tmp.resize( 80 );
        strftime( tmp.data(), 80, "%m/%d/%y %H:%M:%S", localtime( &tm ) );
        files->changeItemPart( tmp, j, 1 );
        tmp.setNum( i.current()->size() );
        files->changeItemPart( tmp, j, 2 );
    }
}

ArchiveInfoDlg::~ArchiveInfoDlg()
{
}

void ArchiveInfoDlg::slotOK()
{
    slotApply();
    accept();
}

void ArchiveInfoDlg::slotApply()
{
    if ( _archive->name() != _archiveName->text() ) {
        _archive->setName( _archiveName->text() );
        _tape->writeIndex();
    }
}

void ArchiveInfoDlg::slotCancel()
{
    reject();
}
