// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <qchkbox.h>
#include <qgrpbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qlined.h>
#include <qpushbt.h>

#include <kseparator.h>

#include "BackupOptDlg.h"

BackupOptDlg::BackupOptDlg( const char* archiveName, const char* file, const char* workingDir, QWidget* parent, const char* name )
        : QDialog( parent, name, TRUE )
{
    setIconText( "KDat: Backup Optoins" );
    setCaption( "KDat: Backup Options" );

    resize( 300, 250 );

    QLabel* lbl1 = new QLabel( "Archive name:", this );
    lbl1->setFixedSize( lbl1->sizeHint() );

    _archiveName = new QLineEdit( this );
    _archiveName->setFixedHeight( _archiveName->sizeHint().height() );
    _archiveName->setText( archiveName );
    
    QLabel* lbl2 = new QLabel( "Source file:", this );
    lbl2->setFixedSize( lbl2->sizeHint() );

    _sourceFile = new QLineEdit( this );
    _sourceFile->setFixedHeight( _sourceFile->sizeHint().height() );
    _sourceFile->setText( file );

    QLabel* lbl3 = new QLabel( "Working directory:", this );
    lbl3->setFixedSize( lbl3->sizeHint() );

    _workingDir = new QLineEdit( this );
    _workingDir->setFixedHeight( _workingDir->sizeHint().height() );
    _workingDir->setText( workingDir );

    _oneFilesystem = new QCheckBox( "Stay on one filesystem", this );
    _oneFilesystem->setChecked( TRUE );
    _oneFilesystem->setFixedHeight( _oneFilesystem->sizeHint().height() );

    _listedIncremental = new QCheckBox( "GNU listed incremental", this );
    _listedIncremental->setChecked( TRUE );
    _listedIncremental->setFixedHeight( _listedIncremental->sizeHint().height() );
    connect( _listedIncremental, SIGNAL( toggled( bool ) ), this, SLOT( incrementalToggled( bool ) ) );

    _group = new QGroupBox( "Incremental Options", this );

    _snapshotLabel = new QLabel( "Snapshot file:", _group );
    _snapshotLabel->setFixedSize( _snapshotLabel->sizeHint() );

    _snapshotFile = new QLineEdit( _group );
    QString snapfile = file;
    if ( snapfile.right( 1 ) != "/" ) {
        snapfile += "/";
    }
    snapfile += "snapshot";
    _snapshotFile->setText( snapfile );
    _snapshotFile->setFixedHeight( _snapshotFile->sizeHint().height() );

    _removeSnapshot = new QCheckBox( "Remove snapshot file before backup", _group );
    _removeSnapshot->setFixedHeight( _removeSnapshot->sizeHint().height() );

    _group->setFixedHeight( _snapshotFile->sizeHint().height() + _removeSnapshot->sizeHint().height() + 32 );

    KSeparator* sep = new KSeparator( this );

    QPushButton* ok     = new QPushButton( "Ok", this );
    ok->setFixedSize( 80, ok->sizeHint().height() );
    QPushButton* cancel = new QPushButton( "Cancel", this );
    cancel->setFixedSize( 80, cancel->sizeHint().height() );

    connect( ok    , SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( cancel, SIGNAL( clicked() ), this, SLOT( reject() ) );

    QVBoxLayout* l1 = new QVBoxLayout( this, 4 );

    QHBoxLayout* l1_1 = new QHBoxLayout();
    l1->addLayout( l1_1 );
    l1_1->addWidget( lbl1 );
    l1_1->addWidget( _archiveName, 1 );

    QHBoxLayout* l1_2 = new QHBoxLayout();
    l1->addLayout( l1_2 );
    l1_2->addWidget( lbl2 );
    l1_2->addWidget( _sourceFile, 1 );

    QHBoxLayout* l1_3 = new QHBoxLayout();
    l1->addLayout( l1_3 );
    l1_3->addWidget( lbl3 );
    l1_3->addWidget( _workingDir, 1 );

    l1->addWidget( _oneFilesystem );
    l1->addWidget( _listedIncremental );
    l1->addWidget( _group );
    l1->addStretch( 1 );
    l1->addWidget( sep );

    QHBoxLayout* l1_4 = new QHBoxLayout();
    l1->addLayout( l1_4 );
    l1_4->addStretch( 1 );
    l1_4->addWidget( ok );
    l1_4->addWidget( cancel );

    QVBoxLayout* l2 = new QVBoxLayout( _group, 8, 4 );
    l2->addSpacing( 12 );

    QHBoxLayout* l2_1 = new QHBoxLayout( 4 );
    l2->addLayout( l2_1 );
    l2_1->addWidget( _snapshotLabel );
    l2_1->addWidget( _snapshotFile, 1 );

    l2->addWidget( _removeSnapshot );
    l2->addStretch( 1 );
}

BackupOptDlg::~BackupOptDlg()
{
}

void BackupOptDlg::incrementalToggled( bool set )
{
    _group->setEnabled( set );
    _snapshotLabel->setEnabled( set );
    _snapshotFile->setEnabled( set );
    _removeSnapshot->setEnabled( set );
}

QString BackupOptDlg::archiveName()
{
    return _archiveName->text();
}

QString BackupOptDlg::file()
{
    return _sourceFile->text();
}

QString BackupOptDlg::workingDir()
{
    return _workingDir->text();
}

bool BackupOptDlg::oneFilesystem()
{
    return _oneFilesystem->isChecked();
}

bool BackupOptDlg::incremental()
{
    return _listedIncremental->isChecked();
}

QString BackupOptDlg::snapshotFile()
{
    return _snapshotFile->text();
}

bool BackupOptDlg::removeSnapshot()
{
    return _removeSnapshot->isChecked();
}
