// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _KDat_h_
#define _KDat_h_

#include <ktopwidget.h>

class KMenuBar;
class KStatusBar;
class KToolBar;
class KTreeList;

class QPixmap;
class QPopupMenu;

class Archive;
class Node;
class Tape;

class KDat : public KTopLevelWidget {
    Q_OBJECT
    KMenuBar*   _menu;
    QPopupMenu* _fileMenu;
    QPopupMenu* _editMenu;
    KToolBar*   _toolbar;
    KStatusBar* _statusBar;
    KTreeList*  _localTree;
    KTreeList*  _tapeTree;
    QPixmap*    _folderOpen;
    QPixmap*    _folderClosed;
    QPixmap*    _file;
    QPixmap*    _archive;
    int         _checkTapeTimer;
    bool        _tapePresent;
    Tape*       _tape;

    static KDat* _instance;

    void setTapePresent( bool tapePresent );
    void fillTapeTree();
    void fillSubTree( Node* node );
    void insertNode( Node* parent, Node* child );
    void indexIndex();
    int calcBackupSize( const QString& workingDir, bool local, const QString& file, bool incremental, const QString& snapshot );

    KDat();
private slots:
    void localExpanded( int index );
    void localCollapsed( int index );
    void localSelected( int index );
    void tapeExpanded( int index );
    void tapeCollapsed( int index );
    void tapeSelected( int index );

    void fileBackup();
    void fileRestore();
    void fileVerify();
    void fileEjectTape();
    void fileIndexTape();
    void fileFormatTape();
    void fileQuit();
    void editTapeInfo();
    void editPreferences();
    void help();

    void slotTapeDevice();
protected:
    void timerEvent( QTimerEvent* e );
public:
    ~KDat();
    static KDat* instance();
public slots:
    void status( const char* msg );
};

#endif
