// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <kapp.h>

#include "Options.h"

Options* Options::_instance = 0;

Options::Options()
{
    _config = KApplication::getKApplication()->getConfig();
}

Options* Options::instance()
{
    if ( _instance == 0 ) {
        _instance = new Options();
    }
    return _instance;
}

void Options::sync()
{
    _config->sync();
}

int Options::getDefaultTapeSize()
{
    return _config->readNumEntry( "defaultTapeSize", 2*1024*1024 );
}

int Options::getTapeBlockSize()
{
    return _config->readNumEntry( "tapeBlockSize", 512 );
}

const QString Options::getTapeDevice()
{
    return _config->readEntry( "tapeDevice", "/dev/tape" );
}

const QString Options::getTarCommand()
{
    return _config->readEntry( "tarCommand", "/bin/tar" );
}

void Options::setDefaultTapeSize( int kbytes )
{
    if ( kbytes != getDefaultTapeSize() ) {
        _config->writeEntry( "defaultTapeSize", kbytes );
        emit sigDefaultTapeSize();
    }
}

void Options::setTapeBlockSize( int bytes )
{
    if ( bytes != getTapeBlockSize() ) {
        _config->writeEntry( "tapeBlockSize", bytes );
        emit sigTapeBlockSize();
    }
}

void Options::setTapeDevice( const char* str )
{
    if ( getTapeDevice() != str ) {
        _config->writeEntry( "tapeDevice", str );
        emit sigTapeDevice();
    }
}

void Options::setTarCommand( const char* str )
{
    if ( getTarCommand() != str ) {
        _config->writeEntry( "tarCommand", str );
        emit sigTarCommand();
    }
}
