// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <stdlib.h>

#include <qcombo.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qlined.h>
#include <qpushbt.h>

#include <kseparator.h>

#include "Options.h"
#include "OptionsDlg.h"

OptionsDlg::OptionsDlg( QWidget* parent, const char* name = 0 )
        : QDialog( parent, name, TRUE )
{
    setCaption( "KDat: Options" );
    setIconText( "KDat: Options" );

    resize( 260, 160 );

    QLabel* lbl1 = new QLabel( "Default tape size", this );
    lbl1->setFixedHeight( lbl1->sizeHint().height() );

    _defaultTapeSize = new QLineEdit( this );
    _defaultTapeSize->setFixedSize( 48, _defaultTapeSize->sizeHint().height() );

    _defaultTapeSizeUnits = new QComboBox( this );
    _defaultTapeSizeUnits->setFixedSize( 48, _defaultTapeSizeUnits->sizeHint().height() );
    _defaultTapeSizeUnits->insertItem( "MB" );
    _defaultTapeSizeUnits->insertItem( "GB" );

    QLabel* lbl2 = new QLabel( "Tape block size", this );
    lbl2->setFixedHeight( lbl2->sizeHint().height() );

    _tapeBlockSize = new QLineEdit( this );
    _tapeBlockSize->setFixedSize( 48, _tapeBlockSize->sizeHint().height() );

    QLabel* lbl3 = new QLabel( "bytes", this );
    lbl3->setFixedSize( 48, lbl3->sizeHint().height() );

    QLabel* lbl4 = new QLabel( "Tape device", this );
    lbl4->setFixedHeight( lbl4->sizeHint().height() );

    _tapeDevice = new QLineEdit( this );
    _tapeDevice->setFixedSize( 100, _tapeDevice->sizeHint().height() );

    QLabel* lbl5 = new QLabel( "Tar command", this );
    lbl5->setFixedHeight( lbl5->sizeHint().height() );

    _tarCommand = new QLineEdit( this );
    _tarCommand->setFixedSize( 100, _tarCommand->sizeHint().height() );

    KSeparator* separator = new KSeparator( this );

    QPushButton* ok     = new QPushButton( "OK"    , this );
    QPushButton* apply  = new QPushButton( "Apply" , this );
    QPushButton* cancel = new QPushButton( "Cancel", this );

    ok->setFixedSize( 80, ok->sizeHint().height() );
    apply->setFixedSize( 80, apply->sizeHint().height() );
    cancel->setFixedSize( 80, cancel->sizeHint().height() );

    connect( ok    , SIGNAL( clicked() ), this, SLOT( slotOK()     ) );
    connect( apply , SIGNAL( clicked() ), this, SLOT( slotApply()  ) );
    connect( cancel, SIGNAL( clicked() ), this, SLOT( slotCancel() ) );

    QVBoxLayout* l1 = new QVBoxLayout( this, 4, 4 );

    QHBoxLayout* l1_1 = new QHBoxLayout();
    l1->addLayout( l1_1 );
    l1_1->addWidget( lbl1, 1 );
    l1_1->addWidget( _defaultTapeSize );
    l1_1->addWidget( _defaultTapeSizeUnits );

    QHBoxLayout* l1_2 = new QHBoxLayout();
    l1->addLayout( l1_2 );
    l1_2->addWidget( lbl2, 1 );
    l1_2->addWidget( _tapeBlockSize );
    l1_2->addWidget( lbl3 );

    QHBoxLayout* l1_3 = new QHBoxLayout();
    l1->addLayout( l1_3 );
    l1_3->addWidget( lbl4, 1 );
    l1_3->addWidget( _tapeDevice );

    QHBoxLayout* l1_4 = new QHBoxLayout();
    l1->addLayout( l1_4 );
    l1_4->addWidget( lbl5, 1 );
    l1_4->addWidget( _tarCommand );

    l1->addStretch( 1 );
    l1->addWidget( separator );

    QHBoxLayout* l1_5 = new QHBoxLayout();
    l1->addLayout( l1_5 );
    l1_5->addStretch( 1 );
    l1_5->addWidget( ok );
    l1_5->addWidget( apply );
    l1_5->addWidget( cancel );

    int size = Options::instance()->getDefaultTapeSize();
    if ( size >= 1024*1024 ) {
        // GB
        size /= 1024*1024;
        _defaultTapeSizeUnits->setCurrentItem( 1 );
    } else {
        // MB
        size /= 1024;
        _defaultTapeSizeUnits->setCurrentItem( 0 );
    }
    QString tmp;
    tmp.setNum( size );
    _defaultTapeSize->setText( tmp );

    tmp.setNum( Options::instance()->getTapeBlockSize() );
    _tapeBlockSize->setText( tmp );

    _tapeDevice->setText( Options::instance()->getTapeDevice() );

    _tarCommand->setText( Options::instance()->getTarCommand() );
}

OptionsDlg::~OptionsDlg()
{
}

void OptionsDlg::slotOK()
{
    slotApply();
    accept();
}

void OptionsDlg::slotApply()
{
    int size = atoi( _defaultTapeSize->text() );
    if ( _defaultTapeSizeUnits->currentItem() == 0 ) {
        // MB
        size *= 1024;
    } else {
        // GB
        size *= 1024*1024;
    }
    Options::instance()->setDefaultTapeSize( size );

    Options::instance()->setTapeBlockSize( atoi( _tapeBlockSize->text() ) );

    Options::instance()->setTapeDevice( _tapeDevice->text() );

    Options::instance()->setTarCommand( _tarCommand->text() );

    Options::instance()->sync();
}

void OptionsDlg::slotCancel()
{
    reject();
}
