// KDat - a tar-based DAT archiver
// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <time.h>

#include <qcombo.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qlined.h>
#include <qpushbt.h>

#include <kseparator.h>
#include <ktablistbox.h>

#include "ArchiveInfoDlg.h"
#include "Options.h"
#include "Tape.h"
#include "TapeInfoDlg.h"

TapeInfoDlg::TapeInfoDlg( Tape* tape, QWidget* parent, const char* name )
        : QDialog( parent, name, TRUE ),
          _tape( tape )
{
    const int LABEL_WIDTH = 72;
    
    setCaption( "KDat: Tape Info" );
    setIconText( "KDat: Tape Info" );

    resize( 400, 300 );

    QLabel* lbl1 = new QLabel( "Tape name:", this );
    lbl1->setFixedSize( LABEL_WIDTH, lbl1->sizeHint().height() );

    _tapeName = new QLineEdit( this );
    _tapeName->setFixedHeight( _tapeName->sizeHint().height() );

    QLabel* lbl2 = new QLabel( "Tape size:", this );
    lbl2->setFixedSize( LABEL_WIDTH, lbl2->sizeHint().height() );

    _tapeSize = new QLineEdit( this );
    _tapeSize->setFixedSize( 48, _tapeSize->sizeHint().height() );

    _tapeSizeUnits = new QComboBox( this );
    _tapeSizeUnits->setFixedSize( 48, _tapeSizeUnits->sizeHint().height() );
    _tapeSizeUnits->insertItem( "MB" );
    _tapeSizeUnits->insertItem( "GB" );

    QLabel* lbl3 = new QLabel( "Tape ID:", this );
    lbl3->setFixedSize( LABEL_WIDTH, lbl3->sizeHint().height() );

    QLabel* lbl4 = new QLabel( _tape->tapeID(), this );
    lbl4->setFixedHeight( lbl4->sizeHint().height() );

    QLabel* lbl5 = new QLabel( "Created on:", this );
    lbl5->setFixedSize( LABEL_WIDTH, lbl5->sizeHint().height() );

    long tm = _tape->createTime();
    QString tmp = ctime( &tm );
    tmp = tmp.stripWhiteSpace();
    QLabel* lbl6 = new QLabel( tmp, this );
    lbl6->setFixedHeight( lbl6->sizeHint().height() );

    QLabel* lbl7 = new QLabel( "Modified on:", this );
    lbl7->setFixedSize( LABEL_WIDTH, lbl7->sizeHint().height() );

    tm = _tape->modTime();
    tmp = ctime( &tm );
    tmp = tmp.stripWhiteSpace();
    QLabel* lbl8 = new QLabel( tmp, this );
    lbl8->setFixedHeight( lbl8->sizeHint().height() );

    QLabel* lbl9 = new QLabel( "Archives:", this );
    lbl9->setFixedHeight( lbl9->sizeHint().height() );

    _archives = new KTabListBox( this, 0, 4 );
    _archives->setColumn( 0, "Name", 210 );
    _archives->setColumn( 1, "Date", 60 );
    _archives->setColumn( 2, "Size", 80 );
    _archives->setColumn( 3, "Files", 40 );
    connect( _archives, SIGNAL( selected( int, int ) ), this, SLOT( slotArchiveInfo( int, int ) ) );

    KSeparator* separator = new KSeparator( this );

    QPushButton* ok     = new QPushButton( "OK"    , this );
    QPushButton* apply  = new QPushButton( "Apply" , this );
    QPushButton* cancel = new QPushButton( "Cancel", this );

    ok->setFixedSize( 80, ok->sizeHint().height() );
    apply->setFixedSize( 80, apply->sizeHint().height() );
    cancel->setFixedSize( 80, cancel->sizeHint().height() );

    connect( ok    , SIGNAL( clicked() ), this, SLOT( slotOK()     ) );
    connect( apply , SIGNAL( clicked() ), this, SLOT( slotApply()  ) );
    connect( cancel, SIGNAL( clicked() ), this, SLOT( slotCancel() ) );

    QVBoxLayout* l1 = new QVBoxLayout( this, 4, 4 );

    QHBoxLayout* l1_1 = new QHBoxLayout();
    l1->addLayout( l1_1 );
    l1_1->addWidget( lbl1 );
    l1_1->addWidget( _tapeName, 1 );

    QHBoxLayout* l1_2 = new QHBoxLayout();
    l1->addLayout( l1_2 );
    l1_2->addWidget( lbl2 );
    l1_2->addWidget( _tapeSize );
    l1_2->addWidget( _tapeSizeUnits );
    l1_2->addStretch( 1 );
    
    QHBoxLayout* l1_3 = new QHBoxLayout();
    l1->addLayout( l1_3 );
    l1_3->addWidget( lbl3 );
    l1_3->addWidget( lbl4, 1 );

    QHBoxLayout* l1_4 = new QHBoxLayout();
    l1->addLayout( l1_4 );
    l1_4->addWidget( lbl5 );
    l1_4->addWidget( lbl6, 1 );

    QHBoxLayout* l1_5 = new QHBoxLayout();
    l1->addLayout( l1_5 );
    l1_5->addWidget( lbl7 );
    l1_5->addWidget( lbl8, 1 );

    l1->addSpacing( 4 );
    l1->addWidget( lbl9 );
    l1->addWidget( _archives, 1 );
    l1->addWidget( separator );

    QHBoxLayout* l1_6 = new QHBoxLayout();
    l1->addLayout( l1_6 );
    l1_6->addStretch( 1 );
    l1_6->addWidget( ok );
    l1_6->addWidget( apply );
    l1_6->addWidget( cancel );

    _tapeName->setText( _tape->tapeName() );
    int size = _tape->tapeSize();
    if ( size >= 1024*1024 ) {
        // GB
        size /= 1024*1024;
        _tapeSizeUnits->setCurrentItem( 1 );
    } else {
        // MB
        size /= 1024;
        _tapeSizeUnits->setCurrentItem( 0 );
    }
    tmp.setNum( size );
    _tapeSize->setText( tmp );

    QListIterator<Archive> i( _tape->archives() );
    int j;
    for ( j = 0, i.toFirst(); i.current(); ++i, j++ ) {
        _archives->appendItem( i.current()->name() );
        time_t tm = i.current()->timeStamp();
        tmp.resize( 80 );
        strftime( tmp.data(), 80, "%m/%d/%y", localtime( &tm ) );
        _archives->changeItemPart( tmp, j, 1 );
        _archives->changeItemPart( toString( (int)((float)( i.current()->endBlock() - i.current()->startBlock() ) * (float)Options::instance()->getTapeBlockSize() / 1024.0 ) + 1 ), j, 2 );
        tmp.setNum( i.current()->files().count() );
        _archives->changeItemPart( tmp, j, 3 );
    }
}

TapeInfoDlg::~TapeInfoDlg()
{
}

void TapeInfoDlg::slotOK()
{
    slotApply();
    accept();
}

void TapeInfoDlg::slotApply()
{
    bool saveIt = FALSE;

    if ( _tape->tapeName() != _tapeName->text() ) {
        saveIt = TRUE;
        _tape->setTapeName( _tapeName->text() );
    }

    int size = atoi( _tapeSize->text() );
    if ( _tapeSizeUnits->currentItem() == 0 ) {
        // MB
        size *= 1024;
    } else {
        // GB
        size *= 1024*1024;
    }

    if ( size != _tape->tapeSize() ) {
        saveIt = TRUE;
        _tape->setTapeSize( size );
    }

    if ( saveIt ) {
        _tape->writeIndex();
    }
}

void TapeInfoDlg::slotCancel()
{
    reject();
}

void TapeInfoDlg::slotArchiveInfo( int index, int )
{
    QListIterator<Archive> i( _tape->archives() );
    int j = index;
    for ( i.toFirst(); j > 0; ++i, j-- );
    if ( i.current() ) {
        ArchiveInfoDlg dlg( _tape, i.current(), this );
        dlg.exec();
        _archives->changeItemPart( i.current()->name(), index, 0 );
    }
}

QString TapeInfoDlg::toString( uint kbytes )
{
    QString str;

    str.setNum( kbytes );
    str += "k";
    for ( int i = str.length() - 4; i > 0; i -= 3 ) {
        str.insert( i, ',' );
    }

    return str;
}
